@@ -17,7 +17,8 @@ class RemovableFileFormField(forms.MultiValueField):
         else:
             initial = None
         self.widget = self.widget(is_image=self.is_image, initial=initial)
-        super(RemovableFileFormField, self).__init__(fields, label=kwargs.pop('label'), required=False)
+        super(RemovableFileFormField, self).__init__(fields, label=kwargs.pop('label'),
+                                                     help_text=kwargs.pop('help_text'), required=False)
 
     def compress(self, data_list):
         return data_list
