@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 import datetime
 
 from django import template
@@ -28,7 +45,9 @@ from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext
 from django.utils.translation import ugettext_lazy as _
 
+from autoreports.admin import ReportAdmin
 from cmsutils.forms.widgets import AJAXAutocompletionWidget
+from oembed.models import ProviderRule, StoredOEmbed
 from transmeta import (canonical_fieldname, get_all_translatable_fields,
                        get_real_fieldname_in_each_language,
                        get_fallback_fieldname)
@@ -39,6 +58,7 @@ from merengue.base.models import BaseContent, ContactInfo
 from merengue.base.widgets import (CustomTinyMCE, ReadOnlyWidget,
                                    RelatedBaseContentWidget)
 from merengue.perms.admin import PermissionAdmin
+from merengue.perms import utils as perms_api
 from genericforeignkey.admin import GenericAdmin
 
 # A flag to tell us if autodiscover is running.  autodiscover will set this to
@@ -248,7 +268,7 @@ def set_field_read_only(field, field_name, obj):
     field.required = False
 
 
-class BaseAdmin(GenericAdmin, admin.ModelAdmin):
+class BaseAdmin(GenericAdmin, ReportAdmin, admin.ModelAdmin):
     html_fields = ()
     autocomplete_fields = {}
     edit_related = ()
@@ -272,6 +292,24 @@ class BaseAdmin(GenericAdmin, admin.ModelAdmin):
                 trans_search_fields.append(f)
         self.search_fields = tuple(trans_search_fields)
 
+    def has_add_permission(self, request):
+        """
+            Overrides Django admin behaviour to add ownership based access control
+        """
+        return perms_api.has_global_permission(request.user, 'manage_portal')
+
+    def has_change_permission(self, request, obj=None):
+        """
+        Overrides Django admin behaviour to add ownership based access control
+        """
+        return self.has_add_permission(request)
+
+    def has_delete_permission(self, request, obj=None):
+        """
+        Overrides Django admin behaviour to add ownership based access control
+        """
+        return self.has_add_permission(request)
+
     def _get_base_content(self, request, object_id=None, model_admin=None):
         if not object_id:
             object_id = self.admin_site.base_object_ids.get(self.tool_name, None)
@@ -297,7 +335,7 @@ class BaseAdmin(GenericAdmin, admin.ModelAdmin):
         self.basecontent = obj
         return obj
 
-    def get_form(self, request, obj=None):
+    def get_form(self, request, obj=None, **kwargs):
         form = super(BaseAdmin, self).get_form(request, obj)
         if hasattr(self, 'readonly_fields'):
             for field_name in self.readonly_fields:
@@ -487,29 +525,47 @@ class BaseCategoryAdmin(BaseAdmin):
     search_fields = (get_fallback_fieldname('name'), )
     prepopulated_fields = {'slug': (get_fallback_fieldname('name'), )}
 
+    def has_add_permission(self, request):
+        """
+            Overrides Django admin behaviour to add ownership based access control
+        """
+        return perms_api.has_global_permission(request.user, 'manage_category')
+
+    def has_change_permission(self, request, obj=None):
+        """
+        Overrides Django admin behaviour to add ownership based access control
+        """
+        return self.has_add_permission(request)
+
+    def has_delete_permission(self, request, obj=None):
+        """
+        Overrides Django admin behaviour to add ownership based access control
+        """
+        return self.has_add_permission(request)
+
 
 class WorkflowBatchActionProvider(object):
 
     def set_as_draft(self, request, queryset):
         return self.change_state(request, queryset, 'draft',
                                  ugettext(u'Are you sure you want to set this items as draft?'),
-                                 'base.can_draft')
+                                 'can_draft')
     set_as_draft.short_description = _("Set as draft")
 
     def set_as_pending(self, request, queryset):
         return self.change_state(request, queryset, 'pending',
                                  ugettext(u'Are you sure you want to set this items as pending?'),
-                                 'base.can_pending')
+                                 'can_pending')
     set_as_pending.short_description = _("Set as pending")
 
     def set_as_published(self, request, queryset):
         return self.change_state(request, queryset, 'published',
                                  ugettext(u'Are you sure you want to set this items as published?'),
-                                 'base.can_publish')
+                                 'can_publish')
     set_as_published.short_description = _("Set as published")
 
     def change_state(self, request, queryset, state, confirm_msg, perm=None):
-        if (perm and not request.user.has_perm(perm)) or not self.has_change_permission(request):
+        if perm and not perms_api.has_permission_in_queryset(queryset, request.user, perm, None) or not self.has_change_permission(request):
             raise PermissionDenied
         selected = request.POST.getlist(admin.ACTION_CHECKBOX_NAME)
         if selected:
@@ -541,18 +597,19 @@ class StatusControlProvider(object):
             if not obj or user in obj.owners.all():
                 options=options.union([o for o in all_options if o[0] in ('draft', 'pending')])
         # Remember that superuser has all the perms
-        if user.has_perm('base.can_draft'):
+        if perms_api.has_permission(obj, user, 'can_draft'):
             options=options.union([o for o in all_options if o[0] == 'draft'])
-        if user.has_perm('base.can_pending'):
+        if perms_api.has_permission(obj, user, 'can_pending'):
             options=options.union([o for o in all_options if o[0] == 'pending'])
-        if user.has_perm('base.can_published'):
+        if perms_api.has_permission(obj, user, 'can_published'):
             options=options.union([o for o in all_options if o[0] == 'published'])
         return options
 
 
 class BaseContentAdmin(BaseAdmin, WorkflowBatchActionProvider, StatusControlProvider, PermissionAdmin):
     change_list_template = "admin/basecontent/change_list.html"
-    list_display = ('name', 'status', 'user_modification_date', 'last_editor')
+    list_display = ('admin_absolute_url', 'status', 'user_modification_date', 'last_editor')
+    list_display_for_select = ('name', 'status', 'user_modification_date', 'last_editor')
     search_fields = ('name', )
     date_hierarchy = 'creation_date'
     list_filter = ('status', 'user_modification_date', 'last_editor', )
@@ -598,44 +655,40 @@ class BaseContentAdmin(BaseAdmin, WorkflowBatchActionProvider, StatusControlProv
                                        confirm_template='admin/basecontent/assign_owners.html')
     assign_owners.short_description = _("Assign owners")
 
+    def has_add_permission(self, request):
+        """
+            Overrides Django admin behaviour to add ownership based access control
+        """
+        return perms_api.has_global_permission(request.user, 'edit')
+
     def has_change_permission(self, request, obj=None):
         """
         Overrides Django admin behaviour to add ownership based access control
         """
-        has_change_perm = super(BaseContentAdmin, self).has_change_permission(request, obj)
-        if has_change_perm:
-            return True
-        if obj == None:
-            return self.has_add_permission(request)
-        elif hasattr(obj, 'can_edit'):
-            return obj.can_edit(request.user)
-        else:
-            return hasattr(obj, 'owners') and request.user in obj.owners.all()
+        if obj:
+            return perms_api.has_permission(obj, request.user, 'edit')
+        return True
+
+    def has_delete_permission(self, request, obj=None):
+        """
+        Overrides Django admin behaviour to add ownership based access control
+        """
+        if obj:
+            return perms_api.has_permission(obj, request.user, 'delete')
+        return True
 
     def has_change_permission_to_any(self, request):
         return super(BaseContentAdmin, self).has_change_permission(request, None)
 
-    def owner_is_needed(self, request):
-        return not self.has_change_permission_to_any(request)
-
-    def queryset(self, request):
-        """
-        Overrides Django admin queryset to add ownership based access control
-        """
-        qs = super(BaseContentAdmin, self).queryset(request)
-        if self.owner_is_needed(request):
-            # cannot edit all contents, only yours
-            qs = qs.filter(owners=request.user)
-        return qs
-
     def get_form(self, request, obj=None, **kwargs):
         """
         Overrides Django admin behaviour
         """
         if not request.user.is_superuser:
             # we remove ownership selection
+            exclude = self.exclude or tuple()
             kwargs.update({
-                'exclude': ['owners'] + list(self.exclude) + kwargs.get("exclude", []),
+                'exclude': ['owners'] + list(exclude) + kwargs.get("exclude", []),
             })
         form = super(BaseContentAdmin, self).get_form(request, obj, **kwargs)
         keys = form.base_fields.keys()
@@ -661,9 +714,8 @@ class BaseContentAdmin(BaseAdmin, WorkflowBatchActionProvider, StatusControlProv
 
         super(BaseContentAdmin, self).save_model(request, obj, form, change)
 
-        if self.owner_is_needed(request):
-            # user automatically get owner of this object
-            obj.owners.add(request.user)
+        # user automatically get owner of this object
+        obj.owners.add(request.user)
 
     def formfield_for_dbfield(self, db_field, **kwargs):
         field = super(BaseContentAdmin, self).formfield_for_dbfield(db_field, **kwargs)
@@ -684,15 +736,15 @@ class BaseContentAdmin(BaseAdmin, WorkflowBatchActionProvider, StatusControlProv
         extra_context = self._base_update_extra_context(extra_context)
         opts = self.model._meta
         app_label = opts.app_label
+        list_display = list(self.list_display_for_select)
 
-        list_display = list(self.list_display)
         try:
             list_display.remove('action_checkbox')
         except ValueError:
             pass
 
         try:
-            cl = ChangeList(request, self.model, list_display, self.list_display_links, self.select_list_filter,
+            cl = ChangeList(request, self.model, list_display, list_display[0], self.select_list_filter,
                 self.date_hierarchy, self.search_fields, self.list_select_related, self.list_per_page, self.list_editable, self)
         except IncorrectLookupParameters:
             if ERROR_FLAG in request.GET.keys():
@@ -996,6 +1048,8 @@ def register(site):
     ## register admin models
     site.register(BaseContent, BaseContentViewAdmin)
     site.register(Site, SiteAdmin)
+    site.register(ProviderRule)
+    site.register(StoredOEmbed)
     register_related_base(site, BaseContent)
     if settings.USE_GIS:
         register_related_gis(site, BaseContent)
@@ -1047,7 +1101,7 @@ if settings.USE_GIS:
             self.fieldsets = (
                 (self.title_first_fieldset, {'fields': ('address', 'postal_code', )}),
                 (title_fieldset,
-                    {'fields': ('main_location', 'borders', )}
+                    {'fields': ('main_location', )}
                 ),
             )
 
