@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 from datetime import datetime
 
 from django import template
@@ -5,7 +22,7 @@ from django.contrib.admin import ModelAdmin
 from django.contrib.admin.sites import AdminSite as DjangoAdminSite
 from django.contrib.admin.sites import AlreadyRegistered
 from django.contrib.contenttypes.models import ContentType
-from django.core.exceptions import ObjectDoesNotExist
+from django.core.exceptions import PermissionDenied, ObjectDoesNotExist
 from django.core.urlresolvers import reverse
 from django.conf import settings
 from django.db.models.base import ModelBase
@@ -13,15 +30,16 @@ from django.http import HttpResponseRedirect, Http404, HttpResponse
 from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.utils.functional import update_wrapper
+from django.utils.text import capfirst
 from django.utils.translation import ugettext as _
 from django.views.decorators.cache import never_cache
 
 from merengue.base.adminforms import UploadConfigForm, BackupForm
 from merengue.base.models import BaseContent
+from merengue.utils import get_all_parents
 
 OBJECT_ID_PREFIX = 'base_object_id_'
 MODEL_ADMIN_PREFIX = 'base_model_admin_'
-PLUGIN_ADMIN_PREFIX = 'plugin_admin'
 
 
 class BaseAdminSite(DjangoAdminSite):
@@ -51,6 +69,45 @@ class BaseAdminSite(DjangoAdminSite):
             inner = never_cache(inner)
         return update_wrapper(inner, view)
 
+    def app_index(self, request, app_label, extra_context=None):
+        user = request.user
+        app_dict = {}
+        for model, model_admin in self._registry.items():
+            if app_label == model._meta.app_label:
+                perms = {'add': True, 'change': True, 'delete': True}
+                model_dict = {
+                    'name': capfirst(model._meta.verbose_name_plural),
+                    'admin_url': '%s/' % model.__name__.lower(),
+                    'perms': perms,
+                }
+                if app_dict:
+                    app_dict['models'].append(model_dict),
+                else:
+                    # First time around, now that we know there's
+                    # something to display, add in the necessary meta
+                    # information.
+                    app_dict = {
+                        'name': app_label.title(),
+                        'app_url': '',
+                        'has_module_perms': True,
+                        'models': [model_dict],
+                    }
+        if not app_dict:
+            raise Http404('The requested admin page does not exist.')
+        # Sort the models alphabetically within each app.
+        app_dict['models'].sort(lambda x, y: cmp(x['name'], y['name']))
+        context = {
+            'title': _('%s administration') % capfirst(app_label),
+            'app_list': [app_dict],
+            'root_path': self.root_path,
+        }
+        context.update(extra_context or {})
+        context_instance = template.RequestContext(request, current_app=self.name)
+        return render_to_response(self.app_index_template or ('admin/%s/app_index.html' % app_label,
+            'admin/app_index.html'), context,
+            context_instance=context_instance,
+        )
+
     def get_urls(self):
         from django.conf.urls.defaults import patterns, url, include
         from django.template.defaultfilters import slugify
@@ -150,16 +207,25 @@ class BaseAdminSite(DjangoAdminSite):
                     # we have to redirect to the content related section
                     section = related_sections.get().real_instance
                     admin_prefix += 'section/section/%s/' % section.id
-                    section_sites = self.related_admin_sites[section.__class__]
+                    parents = get_all_parents(section.__class__)
+                    section_sites = {}
+                    [section_sites.update(self.related_admin_sites.get(parent, {})) for parent in parents]
+                    section_sites.update(self.related_admin_sites[section.__class__])
+                    #section_sites = self.related_admin_sites[section.__class__]
                     for admin_site in section_sites.values():
                         if model in admin_site._registry:
                             admin_prefix += admin_site.name + '/'
                             break
+                elif getattr(self, 'get_plugin_site_prefix_for_model', False):
+                    admin_prefix += self.get_plugin_site_prefix_for_model(model) + '/'
         return HttpResponseRedirect('%s%s/%s/%d/' % (admin_prefix, model._meta.app_label,
                                     model._meta.module_name, content.id))
 
     def site_configuration(self, request):
-        from merengue.base.utils import restore_config
+        from merengue.perms import utils as perms_api
+        if not perms_api.can_manage_site(request.user):
+            raise PermissionDenied
+        from merengue.utils import restore_config
         if request.method == 'POST':
             if request.POST.get('_submit_configuration', None):
                 form_configuration = UploadConfigForm(request.POST, request.FILES)
@@ -180,7 +246,7 @@ class BaseAdminSite(DjangoAdminSite):
                                       context_instance=RequestContext(request))
 
     def save_configuration(self, request):
-        from merengue.base.utils import save_config
+        from merengue.utils import save_config
         zip_name = datetime.now()
         response = HttpResponse(mimetype='application/x-zip-compressed')
         response['Content-Disposition'] = 'attachment; filename="%s.zip"' % zip_name.isoformat('-')
@@ -190,7 +256,7 @@ class BaseAdminSite(DjangoAdminSite):
 
     def save_backup(self, request):
         from cmsutils.db_utils import do_backupdb
-        from merengue.base.utils import save_backupdb
+        from merengue.utils import save_backupdb
         zip_name = 'backup_%s' % datetime.now().isoformat('-')
         response = HttpResponse(mimetype='application/x-zip-compressed')
         response['Content-Disposition'] = 'attachment; filename="%s.zip"' % zip_name
@@ -301,7 +367,7 @@ class AdminSite(BaseAdminSite, RelatedModelRegistrable):
 
     def __init__(self, *args, **kwargs):
         super(AdminSite, self).__init__(*args, **kwargs)
-        self.plugin_site = PluginAdminSite(main_admin_site=self)
+        self._plugin_sites = {}
 
     def get_urls(self):
         from django.conf.urls.defaults import patterns, url, include
@@ -309,30 +375,32 @@ class AdminSite(BaseAdminSite, RelatedModelRegistrable):
         urlpatterns = super(AdminSite, self).get_urls()
 
         # custom url definitions
-        custom_patterns = patterns('',
-            url('^' + PLUGIN_ADMIN_PREFIX + '/',
-                include(self.plugin_site.urls),
-            ),
-        )
-        return custom_patterns + urlpatterns
+        for plugin_name, plugin_site in self._plugin_sites.items():
+            urlpatterns += patterns('',
+                url('^%s/' % plugin_name,
+                    include(plugin_site.urls),
+                ),
+            )
+        return urlpatterns
 
     def index(self, request, extra_context=None):
         extra_context = extra_context or {}
-
         app_dict = {}
         user = request.user
-        for model, model_admin in self.plugin_site._registry.items():
-            app_label = model._meta.app_label
-            has_module_perms = user.has_module_perms(app_label)
+        from merengue.perms import utils as perms_api
+        manage_plugin_content = perms_api.can_manage_plugin_content(request.user)
+        for plugin_name, site in self._plugin_sites.items():
+            app_label = plugin_name
 
             if app_label in app_dict:
                 continue
 
-            if has_module_perms:
+            if manage_plugin_content:
+                name = app_label.split('.')[1:]
                 app_dict[app_label] = {
-                    'name': app_label.title(),
-                    'app_url': PLUGIN_ADMIN_PREFIX + '/' + app_label + '/',
-                    'has_module_perms': has_module_perms,
+                    'name': name and name[0].title() or '',
+                    'app_url': app_label + '/',
+                    'has_module_perms': manage_plugin_content,
                 }
 
         # Sort the apps alphabetically.
@@ -343,20 +411,54 @@ class AdminSite(BaseAdminSite, RelatedModelRegistrable):
             {'plugins': app_dict})
         return super(AdminSite, self).index(request, extra_context)
 
+    def register_plugin_site(self, plugin_name):
+        if plugin_name in self._plugin_sites.keys():
+            return self._plugin_sites[plugin_name]
+        plugin_site = PluginAdminSite(main_admin_site=self, plugin_name=plugin_name)
+        self._plugin_sites[plugin_name]=plugin_site
+        return plugin_site
+
+    def unregister_plugin_site(self, plugin_name):
+        if not plugin_name in self._plugin_sites.keys():
+            return
+        del(self._plugin_sites[plugin_name])
+
+    def get_plugin_site(self, plugin_name):
+        if plugin_name in self._plugin_sites.keys():
+            return self._plugin_sites[plugin_name]
+        return None
+
+    def get_plugin_sites(self):
+        return self._plugin_sites.values()
+
+    def get_plugin_site_prefix_for_model(self, model):
+        for plugin_name, plugin_site in self._plugin_sites.items():
+            if model in plugin_site._registry:
+                return plugin_name
+        return None
+
 
 class PluginAdminSite(BaseAdminSite, RelatedModelRegistrable):
 
     def __init__(self, *args, **kwargs):
         self.main_site = kwargs.pop('main_admin_site', None)
         self.i_am_plugin_site = True
-        self.prefix = PLUGIN_ADMIN_PREFIX
+        self.prefix = kwargs.pop('plugin_name', '')
+        plugin_name = self.prefix.split('.')[1:]
+        self.plugin_name = plugin_name and plugin_name[0] or ''
         super(PluginAdminSite, self).__init__(*args, **kwargs)
+        self.related_admin_sites = self.main_site.related_admin_sites
+        main_admin = reverse('admin:index')
+        self.root_path = '%s%s/' % (main_admin, self.prefix)
 
     def index(self, request):
-        return super(BaseAdminSite, self).index(request, {'title': _('Plugin administration'), 'inplugin': True})
+        return super(BaseAdminSite, self).index(request,
+                                                {'title': _('%(plugin_name)s plugin administration') % {'plugin_name': self.plugin_name},
+                                                 'inplugin': True,
+                                                 'plugin_name': self.plugin_name})
 
     def app_index(self, request, app_label, extra_context=None):
-        return super(PluginAdminSite, self).app_index(request, app_label, {'inplugin': True})
+        return super(PluginAdminSite, self).app_index(request, app_label, {'inplugin': True, 'plugin_name': self.plugin_name})
 
 
 class RelatedAdminSite(BaseAdminSite):
