@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 # -*- coding: utf-8 -*-
 import os
 import re
@@ -314,14 +331,13 @@ class BaseContent(BaseClass):
         verbose_name = _('base content')
         verbose_name_plural = _('base contents')
         abstract = False
-        permissions = (
-            ("can_draft", "Can set as draft"),
-            ("can_pending", "Can set as pending"),
-            ("can_published", "Can set as published"),
-        )
         ordering = (get_fallback_fieldname('name'), )
         #content_view_template = 'content_view.html' # default definition by BaseContentMeta metaclass
 
+    def admin_absolute_url(self):
+        return '<a href="%s">%s</a>' % (self.get_admin_absolute_url(), self.name)
+    admin_absolute_url.allow_tags = True
+
     @classmethod
     def get_menu_name(cls):
         return u"%s_menu" % cls._meta.module_name
@@ -648,22 +664,31 @@ add_introspection_rules(rules, ["^cmsutils\.db\.fields\.AutoSlugField"])
 # ----- south signals handling -----
 
 post_save_receivers = None
+cache_backend = None
 
 
 def handle_pre_migrate(sender, **kwargs):
-    global post_save_receivers
+    global post_save_receivers, cache_backend
+    # remove post save receivers because we cannot to call create_menus signal
     post_save_receivers = post_save.receivers
     post_save.receivers = []
+    # use dummy cache backend because Johnny cache does weird things. See #852
+    cache_backend = settings.CACHE_BACKEND
+    settings.CACHE_BACKEND = 'dummy://'
 
 
 def handle_post_migrate(sender, **kwargs):
-    global post_save_receivers
-    post_save.receivers = post_save_receivers
+    from merengue.pluggable import enable_active_plugins
+    global post_save_receivers, cache_backend
     # site fixtures loading after migration
+    enable_active_plugins()
     for app_name, fixtures in getattr(settings, 'SITE_FIXTURES', {}).items():
         if app_name == kwargs['app']: # only migrate
             for fixture in fixtures:
                 call_command('loaddata', fixture, verbosity=1)
+    # will set again saved receivers and cache backend
+    post_save.receivers = post_save_receivers
+    settings.CACHE_BACKEND = cache_backend
 
 
 pre_migrate.connect(handle_pre_migrate)
