@@ -1,17 +1,41 @@
+# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 # django imports
 from django.db.models import Q
 from django.contrib.auth.models import User
 from django.contrib.auth.models import Group
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist, ImproperlyConfigured
+from django.template import defaultfilters
 
 # permissions imports
+from merengue.perms import ANONYMOUS_ROLE_SLUG
 from merengue.perms.models import ObjectPermission
 from merengue.perms.models import ObjectPermissionInheritanceBlock
 from merengue.perms.models import Permission
 from merengue.perms.models import PrincipalRoleRelation
 from merengue.perms.models import Role
 
+MANAGE_SITE_PERMISION = 'manage_site'
+MANAGE_USER_PERMISION = 'manage_user'
+MANAGE_MULTIMEDIA_PERMISSION = 'manage_multimedia'
+MANAGE_PLUGIN_PERMISSION = 'manage_plugin_content'
+
 # Roles ######################################################################
 
 
@@ -202,7 +226,8 @@ def get_roles(principal, obj=None):
 
     if isinstance(principal, User):
         for group in principal.groups.all():
-            roles.extend(get_local_roles(obj, group))
+            if obj is not None:
+                roles.extend(get_local_roles(obj, group))
             roles.extend(get_roles(group))
 
     return roles
@@ -305,6 +330,44 @@ def remove_permission(role, permission, obj=None):
     return True
 
 
+def has_global_permission(user, codename, roles=None):
+    """Checks whether the passed user has passed permission for passed object.
+
+    **Parameters:**
+
+    codename
+        The permission's codename which should be checked.
+
+    user
+        The user for which the permission should be checked.
+
+    roles
+        If given these roles will be assigned to the user temporarily before
+        the permissions are checked.
+    """
+
+    if roles is None:
+        roles = []
+
+    roles.append(Role.objects.get(slug=ANONYMOUS_ROLE_SLUG))
+
+    if user.is_superuser:
+        return True
+
+    if user.is_anonymous():
+        user = None
+    else:
+        roles.extend(get_roles(user))
+
+    p = ObjectPermission.objects.filter(
+        Q(content__isnull=True, role__in=roles, permission__codename=codename))
+
+    if p:
+        return True
+
+    return False
+
+
 def has_permission(obj, user, codename, roles=None):
     """Checks whether the passed user has passed permission for passed object.
 
@@ -323,12 +386,18 @@ def has_permission(obj, user, codename, roles=None):
         If given these roles will be assigned to the user temporarily before
         the permissions are checked.
     """
+
     if roles is None:
         roles = []
 
+    roles.append(Role.objects.get(slug=ANONYMOUS_ROLE_SLUG))
+
     if user.is_superuser:
         return True
 
+    if not obj:
+        return has_global_permission(user, codename, roles)
+
     if user.is_anonymous():
         user = None
     else:
@@ -341,7 +410,7 @@ def has_permission(obj, user, codename, roles=None):
             Q(content=obj, role__in=roles, permission__codename=codename) |
             Q(content__isnull=True, role__in=roles, permission__codename=codename))
 
-        if p.count() > 0:
+        if p:
             return True
 
         if is_inherited(obj, codename) == False:
@@ -356,6 +425,30 @@ def has_permission(obj, user, codename, roles=None):
     return False
 
 
+def has_permission_in_queryset(queryset, user, codename, roles=None):
+    """Checks whether the passed user has passed permission for passed object.
+
+    **Parameters:**
+
+    queryset
+        The queryset for which the permission should be checked.
+
+    codename
+        The permission's codename which should be checked.
+
+    user
+        The user for which the permission should be checked.
+
+    roles
+        If given these roles will be assigned to the user temporarily before
+        the permissions are checked.
+    """
+    for obj in queryset:
+        if not has_permission(obj, user, codename, roles):
+            return False
+    return True
+
+
 # Inheritance ################################################################
 
 
@@ -437,6 +530,22 @@ def is_inherited(obj, codename):
         return False
 
 
+def can_manage_site(user):
+    return has_global_permission(user, MANAGE_SITE_PERMISION)
+
+
+def can_manage_user(user):
+    return has_global_permission(user, MANAGE_USER_PERMISION)
+
+
+def can_manage_multimedia(user):
+    return has_global_permission(user, MANAGE_MULTIMEDIA_PERMISSION)
+
+
+def can_manage_plugin_content(user):
+    return has_global_permission(user, MANAGE_PLUGIN_PERMISSION)
+
+
 def get_group(id):
     """Returns the group with passed id or None.
     """
@@ -530,7 +639,7 @@ def unregister_permission(codename):
     return True
 
 
-def register_role(name):
+def register_role(name, slug=None):
     """Registers a role with passed name to the framework. Returns the new
     role if the registration was successfully, otherwise False.
 
@@ -538,8 +647,12 @@ def register_role(name):
 
     name
         The unique role name.
+    slug
+        The role slug.
     """
-    role, created = Role.objects.get_or_create(name=name)
+    if slug is None:
+        slug = defaultfilters.slugify(name)
+    role, created = Role.objects.get_or_create(name=name, slug=slug)
     if created:
         return role
     return False
