@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 from os import path
 
 ugettext = lambda s: s # dummy ugettext function, as said on django docs
@@ -44,6 +61,11 @@ MERENGUE_APPS = (
     'merengue.collab',
 )
 
+HTTP_STATUS_CODE_TEMPLATES = {
+    403: '403.html',
+    404: '404.html',
+}
+
 # merengue usual installed apps. you can use this variable in your INSTALLED_APPS project settings
 INSTALLED_APPS = (
     'django.contrib.auth',
@@ -74,6 +96,7 @@ INSTALLED_APPS = (
     'johnny',
     'genericforeignkey',
     'oembed',
+    'ajax_select',
 ) + MERENGUE_APPS
 
 # merengue exclusive middlewares. you have to put at least these middleware in your project settings
@@ -83,6 +106,7 @@ MERENGUE_MIDDLEWARE_CLASSES = (
     'merengue.section.middleware.DebugSectionMiddleware',
     'merengue.middleware.SimplifiedLayoutMiddleware',
     'merengue.middleware.LocaleMiddleware',
+    'merengue.middleware.HttpStatusCodeRendererMiddleware',
     'merengue.pluggable.middleware.ActivePluginsMiddleware',
 )
 
@@ -101,7 +125,7 @@ MIDDLEWARE_CLASSES = (
     'cmsutils.middleware.AutomatizedTestingMiddleware',
 ) + MERENGUE_MIDDLEWARE_CLASSES + (
     #'django.middleware.gzip.GZipMiddleware',
-    #'debug_toolbar.middleware.DebugToolbarMiddleware',
+    'debug_toolbar.middleware.DebugToolbarMiddleware',
     'merengue.section.middleware.ResponseSectionMiddleware',
     #'cmsutils.middleware.I18NFetchFromCacheMiddleware', # this has to be last # removed anonymous cache middleware
 )
@@ -192,6 +216,12 @@ DEBUG_TOOLBAR_EXCLUDED_URLS = (
     r'^/tinyimages/',
 )
 
+# ajax_select
+AJAX_LOOKUP_CHANNELS = {
+    'perms_user': ('merengue.perms.lookups', 'UserLookup'),
+    'perms_group': ('merengue.perms.lookups', 'GroupLookup'),
+}
+
 JQUERY_BASE_MEDIA = 'merengue/js/'
 
 # Customization Comment app for merengue, feedback
@@ -207,6 +237,10 @@ MENU_PORTAL_SLUG = 'portal_menu'
 #    ...}
 SITE_FIXTURES = {}
 
+SERIALIZATION_MODULES = {
+    "xml": "merengue.xml_serializer",
+}
+
 # Prefix for all merengue URLs
 MERENGUE_URLS_PREFIX = 'cms'
 
@@ -214,3 +248,15 @@ MERENGUE_URLS_PREFIX = 'cms'
 LOGIN_URL = MERENGUE_URLS_PREFIX + '/login/'
 LOGOUT_URL = MERENGUE_URLS_PREFIX + '/logout/'
 LOGIN_REDIRECT_URL = '/'
+
+# Merengue test runner
+TEST_RUNNER = 'merengue.test.run_tests'
+
+# Merengue manage file
+MANAGE_FILE = 'manage.py'
+
+# sys.executable
+# /usr/bin/python
+SYS_EXECUTABLE = None
+
+JOHNNY_TABLE_BLACKLIST = ('south_migrationhistory', )
