@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 from django.template import RequestContext
 from django.template.loader import render_to_string
 
@@ -21,6 +38,7 @@ class Viewlet(RegistrableItem):
         viewlet_context = {
             'registered_viewlet': cls.get_registered_item(),
             'viewlet': cls,
+            'template_base': 'viewlet.html',
         }
         viewlet_context.update(context)
         return render_to_string(template_name, viewlet_context,
